******************************************************************************************
******************************************************************************************
**** Code files for "How Elastic Are Preferences for Redistribution:                 *****
**** Evidence from Randomized Survey Experiments."                                   *****                  
******************************************************************************************
*** Authors: Ilyana Kuziemko, Michael Norton, Emmanuel Saez and Stefanie Stantcheva  *****
*** Date: November 2014                                                              *****
*** For questions and comments please contact Stefanie Stantcheva                    *****
*** sstantcheva@fas.harvard.edu                                                      *****
******************************************************************************************
******************************************************************************************


******************************************************************************************
******* Emotional Poverty, Policy and Inequality only Treatment                             
******************************************************************************************
******* input: Inequality_AER_EstateTax.dta, data from the supplementary pure estate tax 
******* (both emotional and neutral) experiments
******* output: main paper and appendix tables for all estate tax results
******************************************************************************************


* Modify the path here to the folder where you placed the datasets

* Please check the variable labels and value labels, which show the survey question asked
* and the answer choices given to respondents.
* Alternatively, you can also check the survey links provided in the main paper.

cd "/Users/stefaniestantcheva/Dropbox/inequality/AER_revision2/data/"

clear
set mem 500m
set more off

cap log close
log using ineq_estate.log, replace

use Inequality_AER_EstateTax.dta, clear

******************************************************************************************
********* Definition of background variables 
******************************************************************************************

gen obama12 = . 
gen temp=party2012==1 if party2012~=.
replace obama12=temp if obama12==.

gen male=gender==1 if gender~=.
gen native=usborn==1 if usborn~=.
gen married=marital==2 if marital~=.
gen white=ethnic==1 if ethnic~=.
gen black=ethnic==2 if ethnic~=.
gen hisp=ethnic==3 if ethnic~=.
gen asian=ethnic==4 if ethnic~=.
gen college=educ>5 if educ~=.
gen fulltime=employ==1 if employ~=.
gen unemp=employ==4 if employ~=.
gen student=employ==5 if employ~=.
gen nilf=employ==6 if employ~=.
qui tab hhincome, missing gen(hhh) 
gen liberal=policyview>3 if policyview~=. 
gen conservative = policyview<=2 if policyview~=. 
tab ethnic, gen(eee)
tab wave, gen(www)

****Create 3-category policyview to compare with polling data
gen policyview3=1 if policyview<3
replace policyview3=2 if policyview==3
replace policyview3=3 if policyview>3 & policyview~=.

******************************************************************************************
********* Definition of outcome variables 
******************************************************************************************

* Binary variable equal to 1 if respondent says should increase tax on millionaires: 
gen inc_mill_yes=tax_mill==1 if tax_mill~=.
* Binary variable equal to 1 if respondent says should increase estate tax: 
gen inc_estate_yes=estate_tax==3 if estate_tax~=.
* Vote for democrat or republican in 2014
gen democrat14=(party2014==1) if party2014~=.
gen republican14 = (party2014 == 2) if party2014~=.

replace minwage = . if wave == 1 // move this to construction file
* The pilot did not have the min wage question
replace foodstamps =. if wave == 1 // move this to construction file

* The pilot did not have the food stamps question
* Generate outcomes increasing in the amount of support for each policy:
gen inc_housing=5-housing if housing~=. 
gen inc_aid=5-aidpoor if aidpoor~=. 
gen inc_mw = 5-minwage if minwage !=. 
gen inc_food = 5-foodstamps if foodstamps !=. 
* Flip around government trust so it's in increasing direction
replace trust_gov=5-trust_government
*Now, 1 = hardly ever trust, 4 = just about always
gen nowaste = . 
replace nowaste = waste_government 
replace deserving= 4-deserving
* Now 1=not at all, 3 = deserving

* Binary outcome "Inequality has increased"
gen ineq_inc_yes=inequality_increase==3 if inequality_increase~=.

* Binary outcome 'Inequality is very serious"
gen ineq_vs=inequality_problem==5 if inequality_problem~=. 

* Binary outcome "Poverty is very serious"
gen pov_vs=poverty_problem==5 if poverty_problem~=. 

* The high income people are deserving of their income
gen deserving_yes=deserving==3 if deserving~=. 
label var deserving_yes "High income people are deserving of their income"

* Trust the government binary variable
gen trust_gov_yes=trust_government>2 if trust_government~=. 
label var trust_gov_yes "Yes, trust the government"

gen petition_high_estate=petition==1 if petition!=.
label var petition_high_estate "Said would petition for higher estate taxes"

gen estate_tax_correct = estate_tax_rate == 1 if estate_tax_rate !=. 
label var estate_tax_correct "Estate Tax response correct"

* Variables that rank the various tools to address inequality
replace tools_inequality_1 = 6-tools_inequality_1
replace tools_inequality_2 = 6-tools_inequality_2
replace tools_inequality_3 = 6-tools_inequality_3
replace tools_inequality_4 = 6-tools_inequality_4
replace tools_inequality_5 = 6-tools_inequality_5

******************************************************************************************
** Do some summary stats for attrition; 
******************************************************************************************

gen anytreat = (treat1 == 1 | treat2 == 1)
egen totaltaken = count(anytreat) 
egen totalcompleted = total(finished)
gen fractioncomplete = totalcompleted/totaltaken

summarize fractioncomplete

** Overall fraction of control group that finished; 
drop totaltaken totalcompleted fractioncomplete
sort anytreat
egen totaltaken = count(anytreat), by(anytreat) 
egen totalcompleted = total(finished), by(anytreat)
gen fractioncomplete = totalcompleted/totaltaken

summarize fractioncomplete if anytreat == 0
summarize fractioncomplete if anytreat == 1

drop anytreat
drop fractioncomplete totalcompleted totaltaken 


local controls "obama12 age policyview hhincome educ male black hisp native unemp nilf student eee* www* married fulltime "  

tab finished
count
count if finished == 0 & gender == .
* there is basically no attrition


# delimit ; 

*************************************************************** ;
****************** FULL RESULTS TABLES FOR APPENDIX ; 
****************************************************************;

gen missing=0 ;
foreach var of varlist `controls' state { ;
replace missing=1 if `var'==. ;
} ;

label var treat1 "Treated (Emotional)" ;
label var treat2 "Treated (Neutral)" ;

eststo clear ;
foreach var of varlist ineq_vs ineq_inc_yes estate_tax_correct pov_vs deserving_yes taxrate1_1 inc_mill_yes inc_estate_yes petition_high_est
tools_inequality_2 tools_inequality_1 { ;
eststo: areg `var' treat1 treat2 `controls' if missing==0, abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
estadd scalar beta_scaled2 = abs(_b[treat2]/`lib_cons'); 

} ;

esttab using estate1.tex, replace fragment booktabs keep(treat1 treat2) label 
mgroups("Ineq. vs." "Ineq. inc." "Estate corr." "Pov. vs." "Deserving" "Top tax" "Mill. tax" "Estate" "Petition" "Charities" "Educ. pol", pattern(1 1 1 1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 beta_scaled2 N, label("Control mean" "Scaled Emot. Effect" "Scaled Neutral Effect" "Obs.")) ;

eststo clear ;
foreach var of varlist inc_mw inc_aid inc_food inc_housing trust_gov_yes purpose_government nowaste democrat14{ ;
eststo: areg `var' treat1 treat2 `controls' if missing==0, abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
estadd scalar beta_scaled2 = abs(_b[treat2]/`lib_cons'); 
} ;

esttab using estate2.tex, replace fragment booktabs keep(treat1 treat2) label 
mgroups("Min. wage" "Aid" "Food stamps" "Housing" "Trust" "Govt scope" "No waste" "Dem. 2014", pattern(1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 beta_scaled2 N, label("Control mean" "Scaled Emot. Effect" "Scaled Neutral Effect" "Obs.")) ;


*************************************************************** ;
******************TABLE FOR MAIN PAPER ;
****************************************************************;



eststo clear ;
foreach var of varlist ineq_vs ineq_inc deserving_yes inc_estate_yes petition_high_est trust_gov_yes estate_tax_correct { ;
eststo: areg `var' treat1 treat2 `controls' if missing==0, abs(state) ;
test _b[treat1] = _b[treat2]; 
local pval = `r(p)' ;
estadd scalar pvalue = `pval' ;
qui sum `var' if treat1==0 & treat2 == 0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
estadd scalar beta_scaled2 = abs(_b[treat2]/`lib_cons'); 
} ;

esttab using estate.tex, replace fragment booktabs keep(treat1 treat2) label 
mgroups("Ineq. v. ser." "Ineq. inc." "Deserving" "Estate tax" "Petition" "Trust" "Estate tax corr.", pattern(1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 beta_scaled2 pvalue N, label("Control mean" "Scaled Emot. Effect" "Scaled Neutral Effect" "P-Value" "Obs.") fmt(3 3 3 3 0)) ;


cap log close; 
