******************************************************************************************
******************************************************************************************
**** Code files for "How Elastic Are Preferences for Redistribution:                 *****
**** Evidence from Randomized Survey Experiments."                                   *****                  
******************************************************************************************
*** Authors: Ilyana Kuziemko, Michael Norton, Emmanuel Saez and Stefanie Stantcheva  *****
*** Date: November 2014                                                              *****
*** For questions and comments please contact Stefanie Stantcheva                    *****
*** sstantcheva@fas.harvard.edu                                                      *****
******************************************************************************************
******************************************************************************************

******************************************************************************************
******* Trust Treatment                             
******************************************************************************************
******* input: Inequality_AER_Trust.dta, data from the negative trust prime experiment
******* output: main paper and appendix tables for trust results
******************************************************************************************


* Modify the path here to the folder where you placed the datasets

* Please check the variable labels and value labels, which show the survey question asked
* and the answer choices given to respondents.

cd "/Users/stefaniestantcheva/Dropbox/inequality/AER_revision2/data/"


clear
set mem 500m
set more off

cap log close
log using ineq_trust.log, replace


use Inequality_AER_Trust.dta, clear

drop if age<18 

gen treat1=.
replace treat1=1 if group == "Negative Trust Treatment"
replace treat1=0 if group == "Control"

tab treat1

******************************************************************************************
********* Definition of background variables 
******************************************************************************************

gen obama12 = . 
gen temp=party2012==1 if party2012~=.
replace obama12=temp if obama12==.

gen male=gender==1 if gender~=.
gen native=usborn==1 if usborn~=.
gen married=marital==2 if marital~=.
gen white=ethnic==1 if ethnic~=.
gen black=ethnic==2 if ethnic~=.
gen hisp=ethnic==3 if ethnic~=.
gen asian=ethnic==4 if ethnic~=.
gen college=educ>5 if educ~=.
gen fulltime=employ==1 if employ~=.
gen parttime=employ==2 if employ~=.
gen unemp=employ==4 if employ~=.
gen student=employ==5 if employ~=.
gen nilf=employ==6 if employ~=.
qui tab hhincome, missing gen(hhh) 
gen poor=hhincome<4 if hhincome~=.
gen liberal=policyview>3 if policyview~=. 
gen conservative = policyview<=2 if policyview~=. 
tab ethnic, gen(eee)
tab batch, gen(www)

****Create 3-category policyview to compare with polling data
gen policyview3=1 if policyview<3
replace policyview3=2 if policyview==3
replace policyview3=3 if policyview>3 & policyview~=.

******************************************************************************************
********* Definition of outcome variables 
******************************************************************************************

* Please also check the definition of all outcome variables described in the Appendix.

* Binary variable equal to 1 if respondent says should increase tax on millionaires: 
gen inc_mill_yes=tax_mill==1 if tax_mill~=.
* Binary variable equal to 1 if respondent says should increase estate tax: 
gen inc_estate_yes=estate_tax==3 if estate_tax~=.
* Vote for democrat or republican in 2014
gen democrat14=(party2014==1) if party2014~=.
gen republican14 = (party2014 == 2) if party2014~=.

* Generate outcomes increasing in the amount of support for each policy:
gen inc_mw = 5-minwage if minwage !=.
gen inc_housing=5-housing if housing~=.
gen inc_aid=5-aidpoor if aidpoor~=.
gen inc_food= 5-foodst if foodst~=.

* Flip around government trust so it's in increasing direction
replace trust_gov=5-trust_government
*Now, 1 = hardly ever trust, 4 = just about always

* Trust the government binary variable
gen trust_gov_yes=trust_government>2 if trust_government~=. 
label var trust_gov_yes "Yes, trust the government"

gen nowaste = . 
replace nowaste = waste_government 

replace deserving=4-deserving

* Binary outcome "Inequality has increased"
gen ineq_inc_yes=inequality_increase==3 if inequality_increase~=.

* Binary outcome 'Inequality is very serious"
gen ineq_vs=inequality_problem==5 if inequality_problem~=. 

* Binary outcome "Poverty is very serious"
gen pov_vs=poverty_problem==5 if poverty_problem~=. 

* The high income people are deserving of their income
gen deserving_yes=deserving==3 if deserving~=. 
label var deserving_yes "High income people are deserving of their income"

gen petition_high_estate=petition==1 if petition!=.
label var petition_high_estate "Said would petition for higher estate taxes"

* Variables that rank the various tools to address inequality
replace tools_inequality_1 = 6-tools_inequality_1
replace tools_inequality_2 = 6-tools_inequality_2
replace tools_inequality_3 = 6-tools_inequality_3
replace tools_inequality_4 = 6-tools_inequality_4
replace tools_inequality_5 = 6-tools_inequality_5

replace finished = 0 if endofsurvey == ""

******************************************************************************************
** Do some summary stats for attrition; 
******************************************************************************************

sort treat1
egen totaltaken = count(treat1), by(treat1)
egen totalcompleted = total(finished), by(treat1)
gen fractioncomplete = totalcompleted/totaltaken

summarize fractioncomplete if treat1 == 0
summarize fractioncomplete if treat1 == 1

drop totaltaken totalcompleted fractioncomplete 

local controls "obama12 age policyview hhincome educ male black hisp native unemp nilf student eee* www* married fulltime "  

# delimit ; 

gen anytreat=treat1==1 ;

cap drop finished ;

gen finished = endofsurv~=""  ;

drop if endofsurv=="";

gen missing=0 ;

*************************************************************** ;
******************TABLE FOR MAIN PAPER ;
****************************************************************;

label var treat1 "Treated";

eststo clear ;
foreach var of varlist trust_gov_yes purpose_government nowaste ineq_vs ineq_inc_yes pov_vs { ;
eststo: areg `var' treat1 `controls' if missing==0, abs(state) ;
qui sum `var' if treat1==0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
} ;

esttab using firststage_trust.tex, replace fragment booktabs keep(treat1) label 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 N, label("Control mean" "Scaled Trust Effect" "Obs."))  ;

eststo clear ;
foreach var of varlist inc_mill_yes inc_estate_yes petition_high_est inc_mw inc_aid inc_food inc_housing tools_inequality_2 { ;
eststo: areg `var' treat1 `controls' if missing==0, abs(state) ;
qui sum `var' if treat1==0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
} ;

esttab using outcomes_trust.tex, replace fragment booktabs keep(treat1) label 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 N, label("Control mean" "Scaled Trust Effect" "Obs."))  ;


*********************************************************************************************;
************************ FULL TABLES FOR APPENDIX *******************************************;
*********************************************************************************************;

eststo clear ;
foreach var of varlist ineq_vs ineq_inc_yes pov_vs deserving_yes taxrate1_1 inc_mill_yes inc_estate_yes petition_high_est { ;
eststo: areg `var' treat1 `controls' if missing==0, abs(state) ;
qui sum `var' if treat1==0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
} ;

esttab using trust1.tex, replace fragment booktabs keep(treat1) label 
mgroups("Ineq. v. ser." "Ineq. inc." "Pov. v. ser." "Deserving" "Top tax" "Mill. tax" "Estate" "Petition", pattern(1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 N, label("Control mean" "Scaled Trust Effect" "Obs."))  ;

eststo clear ;
foreach var of varlist inc_mw inc_aid inc_food inc_housing trust_gov_yes purpose_government nowaste democrat14 tools_inequality_2 
tools_inequality_1 { ;
eststo: areg `var' treat1 `controls' if missing==0, abs(state) ;
qui sum `var' if treat1==0;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled1 = abs(_b[treat1]/`lib_cons'); 
} ;

esttab using trust2.tex, replace fragment booktabs keep(treat1) label 
mgroups("Min wage" "Aid" "Food st." "Housing" "Trust" "Active" "No waste" "Dem. 2014" "Charity" "Educ. pol.", pattern(1 1 1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled1 N, label("Control mean" "Scaled Trust Effect" "Obs."))  ;


cap log close; 
exit ;

